This datasets folder contains datasets from the following sources: 

coupon_carryout.csv and coupon_rest20.csv are from a [UCI Machine Learning Repository dataset](https://archive.ics.uci.edu/dataset/603/in+vehicle+coupon+recommendation); the original data has a CC-by-4.0 license. 

compas.csv (from [this repository](https://github.com/propublica/compas-analysis/blob/master/compas-scores-two-years.csv)) and broward_2y_recidivism (from [this repository](https://github.com/BeanHam/interpretable-machine-learning/blob/master/broward/data/broward_data.csv)) are publicly available recidivism data from broward county, Florida.

monk1.csv and monk2.csv are from a [UCI Machine Learning Repository dataset](https://archive.ics.uci.edu/dataset/70/monk+s+problems); this data has a CC-by-4.0 license. 

tic-tac-toe.csv is from a [UCI Machine Learning Repository dataset](https://archive.ics.uci.edu/dataset/101/tic+tac+toe+endgame); this data has a CC-by-4.0 license.

spiral.csv contains a synthetic 2D dataset created as a part of our 2022 AAAI paper.
